================
EJ-Conversations
================

This is the main conversation app from the EJ platform.

.. image:: https://travis-ci.org/ejplatform/ej-conversations.svg?branch=master
    :target: https://travis-ci.org/ejplatform/ej-conversations
.. image:: https://codecov.io/gh/ejplatform/ej-conversations/branch/master/graph/badge.svg?
    :target: https://codecov.io/gh/ejplatform/ej-conversations
.. image:: https://codeclimate.com/github/ejplatform/ej-conversations/badges/gpa.svg?
    :target: https://codeclimate.com/github/ejplatform/ej-conversations
.. image:: https://codeclimate.com/github/ejplatform/ej-conversations/badges/issue_count.svg?
    :target: https://codeclimate.com/github/ejplatform/ej-conversations


This app only provides basic functionality for managing conversations/comments
in way similar to the EJ platform. It is not coupled to any part of the EJ
platform, including authorization, mathematical analysis, the frontend, etc.